@@ -12,29 +12,36 @@ pub struct ReportConfig {
     yaml: bool,
     verbose: bool,
     strict: bool,
+    incompatible: bool,
     ci_format: Option<CiFormat>,
     output_file: Option<String>,
     project_license: Option<String>,
+    gist: bool,
 }
 
 impl ReportConfig {
+    #[allow(clippy::too_many_arguments)]
     pub fn new(
         json: bool,
         yaml: bool,
         verbose: bool,
         strict: bool,
+        incompatible: bool,
         ci_format: Option<CiFormat>,
         output_file: Option<String>,
         project_license: Option<String>,
+        gist: bool,
     ) -> Self {
         Self {
             json,
             yaml,
             verbose,
             strict,
+            incompatible,
             ci_format,
             output_file,
             project_license,
+            gist,
         }
     }
 }
@@ -112,23 +119,48 @@ impl TableFormatter {
 pub fn generate_report(data: Vec<LicenseInfo>, config: ReportConfig) -> (bool, bool) {
     log(
         LogLevel::Info,
-        &format!("Generating report with config: {:?}", config),
+        &format!("Generating report with config: {config:?}"),
     );
 
     let total_packages = data.len();
     log(
         LogLevel::Info,
-        &format!("Total packages to analyze: {}", total_packages),
+        &format!("Total packages to analyze: {total_packages}"),
     );
 
-    // Filter data if in strict mode to show only restrictive licenses
-    let filtered_data: Vec<LicenseInfo> = if config.strict {
+    let has_restrictive = data.iter().any(|info| *info.is_restrictive());
+    let has_incompatible = data
+        .iter()
+        .any(|info| info.compatibility == LicenseCompatibility::Incompatible);
+
+    log(
+        LogLevel::Info,
+        &format!("Has restrictive licenses: {has_restrictive}"),
+    );
+
+    log(
+        LogLevel::Info,
+        &format!("Has incompatible licenses: {has_incompatible}"),
+    );
+
+    if config.gist {
+        log(LogLevel::Info, "Generating gist summary");
+        print_gist_summary(&data, total_packages, config.project_license.as_deref());
+        return (has_restrictive, has_incompatible);
+    }
+
+    // Filter data if in strict or/and incompatible mode to show only restrictive or/and incompatible licenses
+    let filtered_data: Vec<LicenseInfo> = if config.strict || config.incompatible {
         log(
             LogLevel::Info,
-            "Strict mode enabled, filtering restrictive licenses only",
+            "Strict or/and incompatible mode enabled, filtering restrictive or/and incompatible licenses only",
         );
         data.into_iter()
-            .filter(|info| *info.is_restrictive())
+            .filter(|info| {
+                (config.strict && *info.is_restrictive())
+                    || (config.incompatible
+                        && (info.compatibility == LicenseCompatibility::Incompatible))
+            })
             .collect()
     } else {
         data
@@ -140,21 +172,6 @@ pub fn generate_report(data: Vec<LicenseInfo>, config: ReportConfig) -> (bool, b
     );
     log_debug("Filtered license data", &filtered_data);
 
-    let has_restrictive = filtered_data.iter().any(|info| *info.is_restrictive());
-    let has_incompatible = filtered_data
-        .iter()
-        .any(|info| info.compatibility == LicenseCompatibility::Incompatible);
-
-    log(
-        LogLevel::Info,
-        &format!("Has restrictive licenses: {}", has_restrictive),
-    );
-
-    log(
-        LogLevel::Info,
-        &format!("Has incompatible licenses: {}", has_incompatible),
-    );
-
     if filtered_data.is_empty() {
         println!(
             "\n{}\n",
@@ -182,7 +199,7 @@ pub fn generate_report(data: Vec<LicenseInfo>, config: ReportConfig) -> (bool, b
         // JSON output
         log(LogLevel::Info, "Generating JSON output");
         match serde_json::to_string_pretty(&filtered_data) {
-            Ok(json_output) => println!("{}", json_output),
+            Ok(json_output) => println!("{json_output}"),
             Err(err) => {
                 log_error("Failed to serialize data to JSON", &err);
                 println!("Error: Failed to generate JSON output");
@@ -192,7 +209,7 @@ pub fn generate_report(data: Vec<LicenseInfo>, config: ReportConfig) -> (bool, b
         // YAML output
         log(LogLevel::Info, "Generating YAML output");
         match serde_yaml::to_string(&filtered_data) {
-            Ok(yaml_output) => println!("{}", yaml_output),
+            Ok(yaml_output) => println!("{yaml_output}"),
             Err(err) => {
                 log_error("Failed to serialize data to YAML", &err);
                 println!("Error: Failed to generate YAML output");
@@ -211,6 +228,7 @@ pub fn generate_report(data: Vec<LicenseInfo>, config: ReportConfig) -> (bool, b
             &filtered_data,
             total_packages,
             config.strict,
+            config.incompatible,
             config.project_license.as_deref(),
         );
     }
@@ -284,25 +302,17 @@ fn print_summary_table(
     license_info: &[LicenseInfo],
     total_packages: usize,
     strict: bool,
+    incompatible: bool,
     project_license: Option<&str>,
 ) {
     log(LogLevel::Info, "Printing summary table");
 
-    if strict {
-        log(
-            LogLevel::Info,
-            "Strict mode enabled, showing only restrictive licenses",
-        );
-        print_restrictive_licenses_table(&license_info.iter().collect::<Vec<_>>());
-        return;
-    }
-
     // Print project license if available
     if let Some(license) = project_license {
         println!(
             "\n{} {}",
             "📄".bold(),
-            format!("Project License: {}", license).bold()
+            format!("Project License: {license}").bold()
         );
     }
 
@@ -346,6 +356,22 @@ fn print_summary_table(
         ),
     );
 
+    if strict || incompatible {
+        if strict && !restrictive_licenses.is_empty() {
+            log(
+                LogLevel::Info,
+                "Strict mode enabled, showing only restrictive licenses",
+            );
+            print_restrictive_licenses_table(&restrictive_licenses);
+        }
+        if incompatible && project_license.is_some() && !incompatible_licenses.is_empty() {
+            if let Some(license) = project_license {
+                print_incompatible_licenses_table(&incompatible_licenses, license);
+            }
+        }
+        return;
+    }
+
     // License summary
     let headers = vec!["License Type".to_string(), "Count".to_string()];
 
@@ -379,7 +405,7 @@ fn print_summary_table(
     println!(
         "\n{} {}",
         "📦".bold(),
-        format!("Total dependencies scanned: {}", total_packages).bold()
+        format!("Total dependencies scanned: {total_packages}").bold()
     );
 
     if !restrictive_licenses.is_empty() {
@@ -466,12 +492,9 @@ fn print_incompatible_licenses_table(
     println!(
         "\n{} {}\n",
         "❌".bold(),
-        format!(
-            "Warning: Licenses incompatible with {} found!",
-            project_license
-        )
-        .red()
-        .bold()
+        format!("Warning: Licenses incompatible with {project_license} found!")
+            .red()
+            .bold()
     );
 
     let headers = vec![
@@ -564,7 +587,7 @@ fn print_summary_footer(license_info: &[LicenseInfo], project_license: Option<&s
         );
     }
 
-    println!("  • {} total dependencies", total);
+    println!("  • {total} total dependencies");
 
     if restrictive_count > 0 {
         println!("\n{} {}: Review these dependencies for compliance with your project's licensing requirements.",
@@ -607,8 +630,7 @@ fn output_github_format(
     // Add project license info if available
     if let Some(license) = project_license {
         output.push_str(&format!(
-            "::notice title=Project License::Project is using {} license\n",
-            license
+            "::notice title=Project License::Project is using {license} license\n"
         ));
     }
 
@@ -688,23 +710,23 @@ fn output_github_format(
     if let Some(path) = output_path {
         log(
             LogLevel::Info,
-            &format!("Writing GitHub Actions output to file: {}", path),
+            &format!("Writing GitHub Actions output to file: {path}"),
         );
 
         match fs::write(path, &output) {
-            Ok(_) => println!("GitHub Actions output written to: {}", path),
+            Ok(_) => println!("GitHub Actions output written to: {path}"),
             Err(err) => {
                 log_error(
-                    &format!("Failed to write GitHub Actions output file: {}", path),
+                    &format!("Failed to write GitHub Actions output file: {path}"),
                     &err,
                 );
                 println!("Error: Failed to write GitHub Actions output file");
-                println!("{}", output);
+                println!("{output}");
             }
         }
     } else {
         log(LogLevel::Info, "Writing GitHub Actions output to stdout");
-        print!("{}", output);
+        print!("{output}");
     }
 }
 
@@ -725,9 +747,8 @@ fn output_jenkins_format(
     if let Some(license) = project_license {
         test_cases.push(format!(
             r#"    <testcase classname="feluda.project" name="project_license" time="0">
-        <system-out>Project is using {} license</system-out>
-    </testcase>"#,
-            license
+        <system-out>Project is using {license} license</system-out>
+    </testcase>"#
         ));
     }
 
@@ -735,7 +756,7 @@ fn output_jenkins_format(
         let test_case_name = format!("{}-{}", info.name(), info.version());
         log(
             LogLevel::Info,
-            &format!("Processing test case: {}", test_case_name),
+            &format!("Processing test case: {test_case_name}"),
         );
 
         let mut failures = Vec::new();
@@ -783,8 +804,7 @@ fn output_jenkins_format(
 
         if failures.is_empty() {
             test_cases.push(format!(
-                r#"    <testcase classname="feluda.licenses" name="{}" time="0" />"#,
-                test_case_name
+                r#"    <testcase classname="feluda.licenses" name="{test_case_name}" time="0" />"#
             ));
         } else {
             test_cases.push(format!(
@@ -834,26 +854,106 @@ fn output_jenkins_format(
     if let Some(path) = output_path {
         log(
             LogLevel::Info,
-            &format!("Writing Jenkins JUnit XML to file: {}", path),
+            &format!("Writing Jenkins JUnit XML to file: {path}"),
         );
 
         match fs::write(path, &junit_xml) {
-            Ok(_) => println!("Jenkins JUnit XML output written to: {}", path),
+            Ok(_) => println!("Jenkins JUnit XML output written to: {path}"),
             Err(err) => {
                 log_error(
-                    &format!("Failed to write Jenkins output file: {}", path),
+                    &format!("Failed to write Jenkins output file: {path}"),
                     &err,
                 );
                 println!("Error: Failed to write Jenkins JUnit XML output file");
-                println!("{}", junit_xml); // Fallback to stdout
+                println!("{junit_xml}"); // Fallback to stdout
             }
         }
     } else {
         log(LogLevel::Info, "Writing Jenkins JUnit XML to stdout");
-        println!("{}", junit_xml);
+        println!("{junit_xml}");
     }
 }
 
+// Add gist report function to reporter.rs
+fn print_gist_summary(
+    license_info: &[LicenseInfo],
+    total_packages: usize,
+    project_license: Option<&str>,
+) {
+    use colored::*;
+
+    let restrictive_count = license_info.iter().filter(|i| *i.is_restrictive()).count();
+    let incompatible_count = license_info
+        .iter()
+        .filter(|i| i.compatibility == LicenseCompatibility::Incompatible)
+        .count();
+
+    let project_license_display = project_license.unwrap_or("Not detected");
+
+    println!("\n{}", "🦀 FELUDA GIST".bold().cyan());
+    println!("{}", "━".repeat(50).cyan());
+
+    println!(
+        "│ {:30} │ {}",
+        "Project License".bold(),
+        project_license_display.cyan()
+    );
+    println!(
+        "│ {:30} │ {}",
+        "Total Dependencies Scanned".bold(),
+        total_packages.to_string().cyan()
+    );
+
+    println!("{}", "━".repeat(50).cyan());
+
+    let restrictive_status = if restrictive_count > 0 {
+        format!(
+            "{} {}",
+            "⚠️".yellow(),
+            restrictive_count.to_string().yellow().bold()
+        )
+    } else {
+        format!("{} {}", "✅".green(), "0".green().bold())
+    };
+
+    let incompatible_status = if project_license.is_some() {
+        if incompatible_count > 0 {
+            format!(
+                "{} {}",
+                "❌".red(),
+                incompatible_count.to_string().red().bold()
+            )
+        } else {
+            format!("{} {}", "✅".green(), "0".green().bold())
+        }
+    } else {
+        format!("{} {}", "❓".blue(), "N/A".blue())
+    };
+
+    println!(
+        "│ {:30} │ {}",
+        "Restrictive dependencies".bold(),
+        restrictive_status
+    );
+    println!(
+        "│ {:30} │ {}",
+        "Incompatible dependencies".bold(),
+        incompatible_status
+    );
+
+    println!("{}", "━".repeat(50).cyan());
+
+    let overall_status = if restrictive_count > 0 || incompatible_count > 0 {
+        format!("{} {}", "⚠️".yellow(), "NEEDS ATTENTION".yellow().bold())
+    } else {
+        format!("{} {}", "✨".green(), "ALL GOOD".green().bold())
+    };
+
+    println!("│ {:30} │ {}", "Recommendation".bold(), overall_status);
+
+    println!("{}\n", "━".repeat(50).cyan());
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -919,7 +1019,7 @@ mod tests {
     #[test]
     fn test_generate_report_empty_data() {
         let data = vec![];
-        let config = ReportConfig::new(false, false, false, false, None, None, None);
+        let config = ReportConfig::new(false, false, false, false, false, None, None, None, false);
         let result = generate_report(data, config);
         assert_eq!(result, (false, false)); // No restrictive or incompatible licenses
     }
@@ -932,9 +1032,11 @@ mod tests {
             false,
             false,
             false,
+            false,
             None,
             None,
             Some("MIT".to_string()),
+            false,
         );
         let result = generate_report(data, config);
         assert_eq!(result, (true, true)); // Has both restrictive and incompatible licenses
@@ -948,9 +1050,11 @@ mod tests {
             false,
             false,
             true,
+            false,
             None,
             None,
             Some("MIT".to_string()),
+            false,
         );
         let result = generate_report(data, config);
         assert_eq!(result, (true, true)); // In strict mode, still has both restrictive and incompatible
@@ -964,9 +1068,11 @@ mod tests {
             false,
             false,
             false,
+            false,
             None,
             None,
             Some("MIT".to_string()),
+            false,
         );
         let result = generate_report(data, config);
         assert_eq!(result, (true, true));
@@ -980,9 +1086,11 @@ mod tests {
             true,
             false,
             false,
+            false,
             None,
             None,
             Some("MIT".to_string()),
+            false,
         );
         let result = generate_report(data, config);
         assert_eq!(result, (true, true));
@@ -996,9 +1104,11 @@ mod tests {
             false,
             true,
             false,
+            false,
             None,
             None,
             Some("MIT".to_string()),
+            false,
         );
         let result = generate_report(data, config);
         assert_eq!(result, (true, true));
@@ -1007,7 +1117,7 @@ mod tests {
     #[test]
     fn test_generate_report_no_project_license() {
         let data = get_test_data_with_unknown_compatibility();
-        let config = ReportConfig::new(false, false, false, false, None, None, None);
+        let config = ReportConfig::new(false, false, false, false, false, None, None, None, false);
         let result = generate_report(data, config);
         assert_eq!(result, (true, false)); // Has restrictive but no incompatible since no project license
     }
@@ -1022,9 +1132,11 @@ mod tests {
             false,
             false,
             false,
+            false,
             Some(CiFormat::Github),
             Some(output_path.to_str().unwrap().to_string()),
             Some("MIT".to_string()),
+            false,
         );
 
         let result = generate_report(data, config);
@@ -1033,7 +1145,7 @@ mod tests {
         let content = match fs::read_to_string(&output_path) {
             Ok(content) => content,
             Err(err) => {
-                panic!("Failed to read output file: {}", err);
+                panic!("Failed to read output file: {err}");
             }
         };
 
@@ -1053,9 +1165,11 @@ mod tests {
             false,
             false,
             false,
+            false,
             Some(CiFormat::Jenkins),
             Some(output_path.to_str().unwrap().to_string()),
             Some("MIT".to_string()),
+            false,
         );
 
         let result = generate_report(data, config);
@@ -1064,7 +1178,7 @@ mod tests {
         let content = match fs::read_to_string(&output_path) {
             Ok(content) => content,
             Err(err) => {
-                panic!("Failed to read output file: {}", err);
+                panic!("Failed to read output file: {err}");
             }
         };
 
@@ -1085,9 +1199,11 @@ mod tests {
             false,
             false,
             false,
+            false,
             Some(CiFormat::Jenkins),
             Some(output_path.to_str().unwrap().to_string()),
             None,
+            false,
         );
 
         let result = generate_report(data, config);
@@ -1096,7 +1212,7 @@ mod tests {
         let content = match fs::read_to_string(&output_path) {
             Ok(content) => content,
             Err(err) => {
-                panic!("Failed to read output file: {}", err);
+                panic!("Failed to read output file: {err}");
             }
         };
 
@@ -1190,9 +1306,11 @@ mod tests {
             false, // yaml
             false, // verbose
             false, // strict
+            false, // incompatible
             None,  // ci_format
             None,  // output_file
             None,  // project_license
+            false, // gist
         );
 
         assert!(!config.json);
@@ -1228,9 +1346,11 @@ mod tests {
             false,
             false,
             false,
+            false,
             None,
             None,
             Some("MIT".to_string()),
+            false,
         );
         let (has_restrictive, has_incompatible) = generate_report(data, config);
 
@@ -1262,9 +1382,11 @@ mod tests {
             false,
             false,
             false,
+            false,
             None,
             None,
             Some("MIT".to_string()),
+            false,
         );
         let (has_restrictive, has_incompatible) = generate_report(data, config);
 
@@ -1296,9 +1418,11 @@ mod tests {
             false,
             false,
             true,
+            false,
             None,
             None,
             Some("MIT".to_string()),
+            false,
         );
         let (has_restrictive, has_incompatible) = generate_report(data, config);
 
@@ -1316,7 +1440,7 @@ mod tests {
             compatibility: LicenseCompatibility::Compatible,
         }];
 
-        let config = ReportConfig::new(true, false, false, false, None, None, None);
+        let config = ReportConfig::new(true, false, false, false, false, None, None, None, false);
         let (has_restrictive, has_incompatible) = generate_report(data, config);
 
         assert!(!has_restrictive);
@@ -1333,7 +1457,7 @@ mod tests {
             compatibility: LicenseCompatibility::Compatible,
         }];
 
-        let config = ReportConfig::new(false, true, false, false, None, None, None);
+        let config = ReportConfig::new(false, true, false, false, false, None, None, None, false);
         let (has_restrictive, has_incompatible) = generate_report(data, config);
 
         assert!(!has_restrictive);
@@ -1355,9 +1479,11 @@ mod tests {
             false,
             true,
             false,
+            false,
             None,
             None,
             Some("MIT".to_string()),
+            false,
         );
         let (has_restrictive, has_incompatible) = generate_report(data, config);
 
@@ -1380,9 +1506,11 @@ mod tests {
             false,
             false,
             false,
+            false,
             Some(CiFormat::Github),
             None,
             Some("MIT".to_string()),
+            false,
         );
 
         let (has_restrictive, has_incompatible) = generate_report(data, config);
@@ -1471,12 +1599,14 @@ mod tests {
             false,
             true,
             false,
+            false,
             Some(CiFormat::Github),
             Some("test.txt".to_string()),
             Some("MIT".to_string()),
+            false,
         );
 
-        let debug_str = format!("{:?}", config);
+        let debug_str = format!("{config:?}");
         assert!(debug_str.contains("ReportConfig"));
         assert!(debug_str.contains("json: true"));
         assert!(debug_str.contains("yaml: false"));
